@@ -7,7 +7,7 @@ Attean::API::Binding - Name to term bindings
 
 =head1 VERSION
 
-This document describes Attean::API::Binding version 0.010
+This document describes Attean::API::Binding version 0.011
 
 =head1 DESCRIPTION
 
@@ -71,7 +71,7 @@ otherwise.
 
 use Type::Tiny::Role;
 
-package Attean::API::Binding 0.010 {
+package Attean::API::Binding 0.011 {
 	use Moo::Role;
 	use Scalar::Util qw(blessed);
 	use List::MoreUtils qw(zip);
@@ -173,7 +173,7 @@ C<< $binding >>.
 	}
 }
 
-package Attean::API::TripleOrQuadPattern 0.010 {
+package Attean::API::TripleOrQuadPattern 0.011 {
 	use Scalar::Util qw(blessed);
 	use Attean::RDF;
 	use Attean::API::Query;
@@ -262,12 +262,21 @@ package Attean::API::TripleOrQuadPattern 0.010 {
 	}
 }
 
-package Attean::API::TripleOrQuad 0.010 {
+package Attean::API::TripleOrQuad 0.011 {
 	use Moo::Role;
+	use List::MoreUtils qw(any);
+	use Carp;
 	with 'Attean::API::TripleOrQuadPattern';
+
+	sub BUILD {
+		my $self = shift;
+		if (any { $_->does('Attean::API::Variable') } $self->values) {
+			croak 'Use a Pattern class to construct when using variables';
+		}
+	}
 }
 
-package Attean::API::TriplePattern 0.010 {
+package Attean::API::TriplePattern 0.011 {
 	use Moo::Role;
 	use List::MoreUtils qw(zip);
 	use Scalar::Util qw(blessed);
@@ -310,7 +319,7 @@ package Attean::API::TriplePattern 0.010 {
 	with 'Attean::API::TripleOrQuadPattern', 'Attean::API::Binding';
 }
 
-package Attean::API::Triple 0.010 {
+package Attean::API::Triple 0.011 {
 	use Moo::Role;
 	
 	if ($ENV{ATTEAN_TYPECHECK}) {
@@ -345,7 +354,7 @@ package Attean::API::Triple 0.010 {
 	with 'Attean::API::TriplePattern', 'Attean::API::TripleOrQuad', 'Attean::API::Binding';
 }
 
-package Attean::API::QuadPattern 0.010 {
+package Attean::API::QuadPattern 0.011 {
 	use Scalar::Util qw(blessed);
 	use Moo::Role;
 	
@@ -378,7 +387,7 @@ package Attean::API::QuadPattern 0.010 {
 	with 'Attean::API::TripleOrQuadPattern', 'Attean::API::Binding';
 }
 
-package Attean::API::Quad 0.010 {
+package Attean::API::Quad 0.011 {
 	use Moo::Role;
 	
 	if ($ENV{ATTEAN_TYPECHECK}) {
@@ -405,7 +414,7 @@ package Attean::API::Quad 0.010 {
 }
 
 
-package Attean::API::Result 0.010 {
+package Attean::API::Result 0.011 {
 	use Moo::Role;
 	use Scalar::Util qw(refaddr);
 	use Types::Standard qw(HashRef);
