@@ -7,7 +7,7 @@ Attean::API::Term - RDF Terms
 
 =head1 VERSION
 
-This document describes Attean::API::Term version 0.010
+This document describes Attean::API::Term version 0.011
 
 =head1 DESCRIPTION
 
@@ -41,7 +41,7 @@ Returns a string serialization of the term.
 
 =cut
 
-package Attean::API::Term 0.010 {
+package Attean::API::Term 0.011 {
 	use Moo::Role;
 	
 	with 'Attean::API::TermOrVariable', 'Attean::API::ResultOrTerm';
@@ -106,7 +106,7 @@ Returns true if the term has a true SPARQL "effective boolean value", false othe
 	}
 }
 
-package Attean::API::Literal 0.010 {
+package Attean::API::Literal 0.011 {
 	use Moo::Role;
 	use IRI;
 	use Scalar::Util qw(blessed);
@@ -166,7 +166,7 @@ package Attean::API::Literal 0.010 {
 		my $dt = $self->datatype;
 		if ($self->does('Attean::API::NumericLiteral') and $dt->value eq 'http://www.w3.org/2001/XMLSchema#integer') {
 			if ($self->value =~ /^\d+$/) {
-				my $t	= AtteanX::Parser::Turtle::Token->fast_constructor( INTEGER, -1, -1, -1, -1, [$self->value] );
+				my $t	= AtteanX::SPARQL::Token->fast_constructor( INTEGER, -1, -1, -1, -1, [$self->value] );
 				return Attean::ListIterator->new( values => [$t], item_type => 'AtteanX::SPARQL::Token' );
 			}
 		}
@@ -178,7 +178,7 @@ package Attean::API::Literal 0.010 {
 			push(@tokens, $l);
 		} else {
 			if ($dt->value ne 'http://www.w3.org/2001/XMLSchema#string') {
-				push(@tokens, AtteanX::Parser::Turtle::Token->hathat);
+				push(@tokens, AtteanX::SPARQL::Token->hathat);
 				push(@tokens, $dt->sparql_tokens->elements);
 			}
 		}
@@ -290,7 +290,7 @@ package Attean::API::Literal 0.010 {
 	};
 }
 
-package Attean::API::DateTimeLiteral 0.010 {
+package Attean::API::DateTimeLiteral 0.011 {
 	use Moo::Role;
 	use DateTime::Format::W3CDTF;
 	use namespace::clean;
@@ -301,12 +301,12 @@ package Attean::API::DateTimeLiteral 0.010 {
 	}
 }
 
-package Attean::API::CanonicalizingLiteral 0.010 {
+package Attean::API::CanonicalizingLiteral 0.011 {
 	use Moo::Role;
 	requires 'canonicalized_term';
 }
 
-package Attean::API::NumericLiteral 0.010 {
+package Attean::API::NumericLiteral 0.011 {
 	use Moo::Role;
 	use Scalar::Util qw(blessed looks_like_number);
 	use namespace::clean;
@@ -497,7 +497,7 @@ package Attean::API::NumericLiteral 0.010 {
 	with 'Attean::API::Literal', 'Attean::API::CanonicalizingLiteral';
 }
 
-package Attean::API::Blank 0.010 {
+package Attean::API::Blank 0.011 {
 	use Moo::Role;
 	use Scalar::Util qw(blessed);
 	use AtteanX::SPARQL::Constants;
@@ -523,7 +523,7 @@ package Attean::API::Blank 0.010 {
 	}
 }
 
-package Attean::API::IRI 0.010 {
+package Attean::API::IRI 0.011 {
 	use Moo::Role;
 	use IRI;
 	use Scalar::Util qw(blessed);
