@@ -7,7 +7,7 @@ Attean::QueryPlanner - Query planner
 
 =head1 VERSION
 
-This document describes Attean::QueryPlanner version 0.010
+This document describes Attean::QueryPlanner version 0.011
 
 =head1 SYNOPSIS
 
@@ -34,7 +34,7 @@ use Attean::Algebra;
 use Attean::Plan;
 use Attean::Expression;
 
-package Attean::QueryPlanner 0.010 {
+package Attean::QueryPlanner 0.011 {
 	use Moo;
 	use Encode qw(encode);
 	use Attean::RDF;
@@ -49,7 +49,7 @@ package Attean::QueryPlanner 0.010 {
 	use Math::Cartesian::Product;
 	use namespace::clean;
 
-	with 'Attean::API::QueryPlanner';
+	with 'Attean::API::QueryPlanner', 'MooX::Log::Any';
 	has 'counter' => (is => 'rw', isa => Int, default => 0);
 
 =back
@@ -107,7 +107,7 @@ the supplied C<< $active_graph >>.
 			if (@plans) {
 				return @plans; # trust that the model knows better than us what plans are best
 			} else {
-# 				warn "*** Model did not provide plans: $model";
+ 				$self->log->info("*** Model did not provide plans: $model");
 			}
 		}
 		
@@ -451,6 +451,13 @@ the supplied C<< $active_graph >>.
 				push(@plans, Attean::Plan::Construct->new(triples => $algebra->triples, children => [$plan], distinct => 0, ordered => []));
 			}
 			return @plans;
+		} elsif ($algebra->isa('Attean::Algebra::Describe')) {
+			my @children	= $self->plans_for_algebra($child, $model, $active_graphs, $default_graphs, @_);
+			my @plans;
+			foreach my $plan (@children) {
+				push(@plans, Attean::Plan::Describe->new(terms => $algebra->terms, graph => $active_graphs, children => [$plan], distinct => 0, ordered => []));
+			}
+			return @plans;
 		} elsif ($algebra->isa('Attean::Algebra::Group')) {
 		}
 		die "Unimplemented algebra evaluation for: " . $algebra->as_string;
