@@ -4,7 +4,7 @@ AtteanX::Parser::SPARQLJSON - SPARQL JSON Parser
 
 =head1 VERSION
 
-This document describes AtteanX::Parser::SPARQLJSON version 0.010
+This document describes AtteanX::Parser::SPARQLJSON version 0.011
 
 =head1 SYNOPSIS
 
@@ -37,7 +37,7 @@ This document describes AtteanX::Parser::SPARQLJSON version 0.010
 use v5.14;
 use warnings;
 
-package AtteanX::Parser::SPARQLJSON 0.010 {
+package AtteanX::Parser::SPARQLJSON 0.011 {
 	use Attean;
 	use Moo;
 	use JSON;
@@ -96,6 +96,8 @@ package AtteanX::Parser::SPARQLJSON 0.010 {
 							my $data	= $value->{value};
 							if (my $lang = $value->{'xml:lang'}) {
 								$data{ $v }	= Attean::Literal->new( value => $data, language => $lang );
+							} elsif (my $dt = $value->{'datatype'}) {
+								$data{ $v }	= Attean::Literal->new( value => $data, datatype => $dt );
 							} else {
 								$data{ $v }	= Attean::Literal->new( $data );
 							}
